@@ -26,6 +26,13 @@ class TestContainer:
         assert ["lolA", "lolB"] == self.sut.get_tagged("tag1")
         assert ["lolA", "lolC"] == self.sut.get_tagged("tag2")
 
+    def test_it_should_get_dict_by_tags(self):
+        self.sut.add_service("a", lambda: "lolA", tags=["tag1", "tag2"])
+        self.sut.add_service("b", lambda: "lolB", tags=["tag1"])
+        self.sut.add_service("c", lambda: "lolC", tags=["tag2"])
+        assert {"a": "lolA", "b": "lolB"} == self.sut.get_tagged("#tag1")
+        assert {"a": "lolA", "c": "lolC"} == self.sut.get_tagged("#tag2")
+
     def test_it_should_inject_kwargs(self):
         self.sut.add_service(Container, lambda: "lol")
 
